@@ -2,7 +2,7 @@
 """Client implentation of the http://www.pypaste.com/services/json API."""
 
 __author__ = 'Matt Kemp <matt@matticus.org>'
-__version__ = 'pypaster 0.5.2 8/27/08'
+__version__ = 'pypaster 0.5.3 8/27/08'
 __license__ = """
 Copyright (c) 2008 Matt Kemp <matt@mattikus.com>
 
@@ -107,7 +107,12 @@ def post_string(snippet, title, language):
 
 def post_file(fp, title, language):
 
-    return post_string(fp.read(), title=title, language=language)
+    try:
+        snippet = fp.read()
+    except KeyboardInterrupt, e:
+        sys.exit('\n')
+
+    return post_string(snippet, title=title, language=language)
 
 def main():
     from optparse import OptionParser
@@ -125,7 +130,7 @@ def main():
                       help='output to FILENAME instead of stdout')
     parser.add_option('--get-languages', dest='getlang', action='store_true',
                       help='gets a list of all supported languages and exit')
-    parser.set_usage("%prog [options] filename")
+    parser.set_usage("%prog [options] [file1 file2 ...]")
     parser.set_description(__doc__)
 
     opts, args = parser.parse_args()
@@ -156,9 +161,11 @@ def main():
         else:
             for filename in args:
                 if not opts.title:
-                    opts.title = os.path.basename(filename)
-                snippet = open(filename)
-                print post_file(snippet, opts.title, opts.language)
+                    title = os.path.basename(filename)
+                else:
+                    title = opts.title
+                snippet = open(filename, 'r')
+                print post_file(snippet, title, opts.language)
                 snippet.close()
 
 
